/* --COPYRIGHT--,BSD
 * Copyright (c) 2017, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
/******************************************************************************
 * MSP432E4 Example Project to demonstrate Bit Banded output.
 *
 * Description: In this example the SysTick Timer is configured to generate an
 * interrupt once every 1 second and on every interrupt the LED D2 Port pin is
 * written. The data to be written is switched from 00 -> 01 -> 10 -> 11 -> 00.
 *
 *                MSP432E401Y
 *             ------------------
 *         /|\|                  |
 *          | |                  |
 *          --|RST            PN0|--> LED D2
 *            |               PN1|--> LED D1
 *            |                  |
 *            |                  |
 *            |                  |
 *            |                  |
 * Author: Amit Ashara
*******************************************************************************/
/* DriverLib Includes */
#include <ti/devices/msp432e4/driverlib/driverlib.h>

/* Standard Includes */
#include <stdint.h>
#include <stdbool.h>

volatile uint32_t gpioState = 0;

void SysTick_Handler(void)
{
    if(gpioState != 3)
    {
        gpioState++;
    }
    else
    {
        gpioState = 0;
    }

    /* Write the new value of GPIO to the port-pin. The API will generate
     * the bit banded address to write to the specific port pin */
    MAP_GPIOPinWrite(GPIO_PORTN_BASE, GPIO_PIN_0, gpioState);

}

int main(void)
{
    uint32_t systemClock;
    uint32_t ui32Loop;
    /* Configure the system clock for 16 MHz */
    systemClock = MAP_SysCtlClockFreqSet((SYSCTL_XTAL_25MHZ | SYSCTL_OSC_MAIN |
                                          SYSCTL_USE_PLL | SYSCTL_CFG_VCO_480),
                                          16000000);

    /* Enable the clock to the GPIO Port N and wait for it to be ready */
    MAP_SysCtlPeripheralEnable(SYSCTL_PERIPH_GPIOD);
    MAP_SysCtlPeripheralEnable(SYSCTL_PERIPH_GPION);
    while(!(SysCtlPeripheralReady(SYSCTL_PERIPH_GPION)))
    {

    }

    /* Configure the GPIO PN0-PN1 as output */
    MAP_GPIOPinTypeGPIOOutput(GPIO_PORTN_BASE, (GPIO_PIN_0 | GPIO_PIN_1));
    MAP_GPIOPinTypeGPIOOutput(GPIO_PORTD_BASE, (GPIO_PIN_2 | GPIO_PIN_3));
    MAP_GPIOPinWrite(GPIO_PORTN_BASE, (GPIO_PIN_0 | GPIO_PIN_1), 0);

//    HWREG(GPIO_PORTD_BASE + (0x00 + (GPIO_PIN_2 << 2))) = 0x8;

    /* Enable the SysTick timer to generate an interrupt every 1 second */
    MAP_SysTickPeriodSet(systemClock);
    MAP_SysTickIntEnable();
    MAP_SysTickEnable();
  //  MAP_GPIOPinWrite(GPIO_PORTD_BASE, GPIO_PIN_2, 0x4);
  //    HWREG(GPIO_PORTD_BASE + (0x00 + ((GPIO_PIN_2|GPIO_PIN_3) << 2))) = 0xFF;
    GPIOD->LOCK = GPIO_LOCK_KEY;
    GPIOD->CR = 0x80;
    GPIOD->AFSEL |= 0x80;
    GPIOD->DEN |= 0x80;
    GPIOD->PDR |= 0x80;
    GPIOD->PCTL |= 0x80000000;
    GPIOD->LOCK = GPIO_LOCK_KEY;
    GPIOD->CR = 0x7f;
//    GPIOC->LOCK = 0;
    while(1)
    {
        for(ui32Loop = 0; ui32Loop < 200000; ui32Loop++)
        {
        }
    }
}


void NMI_Handler(void)
{
        HWREG(GPIO_PORTD_BASE + (0x00 + ((GPIO_PIN_2|GPIO_PIN_3) << 2))) = 0xFF;
}
